@@ -252,7 +252,18 @@ class Freezer:
 
     def _copy_package_data(self, module: Module, target_dir: Path) -> None:
         """Copy any non-Python files to the target directory."""
-        ignore_patterns = ("__pycache__", "*.py", "*.pyc", "*.pyo")
+        ignore_patterns = [
+            "*.pxd",
+            "*.py",
+            "*.pyc",
+            "*.pyi",
+            "*.pyo",
+            "*.pyx",
+            "__pycache__",
+            "py.typed",
+        ]
+        if not IS_MACOS:
+            ignore_patterns.append(".DS_store")
 
         def copy_tree(
             source_dir: Path, target_dir: Path, excludes: set[str]
@@ -599,7 +610,9 @@ class Freezer:
         finder: ModuleFinder = self.finder
         cache_path = finder.cache_path
 
-        modules = [m for m in finder.modules if m.name not in finder.excludes]
+        modules: list[Module] = [
+            m for m in finder.modules if m.name not in finder.excludes
+        ]
         for module in finder.namespaces:
             # if namespace package should be written to zip file, convert it
             # to regular package, since then zipimport doesn't support PEP420
@@ -663,8 +676,23 @@ class Freezer:
                     and module.file is not None
                     and include_in_file_system == 0
                 ):
-                    parts = mod_name_parts[:-1]
-                    parts.append(module.file.name)
+                    parts = mod_name_parts.copy()
+                    if module.file.name.startswith("__init__."):
+                        # if a module init is distributed as compiled like
+                        # __init__.pyd, it should be copied with a new name
+                        # ending with the name of the parent module, and it
+                        # should be imported in the fake code.
+                        last = parts[-1]
+                        source = f"from {module.name}.{last} import *"
+                        module.code = compile(
+                            source, "__init__.py", "exec", dont_inherit=True
+                        )
+                        parts.append(
+                            module.file.name.replace("__init__.", f"{last}.")
+                        )
+                    else:
+                        parts.pop()
+                        parts.append(module.file.name)
                     target = target_lib_dir / ".".join(parts)
                     files_to_copy.append((module, target))
 
@@ -687,7 +715,10 @@ class Freezer:
                 if include_in_file_system >= 1 and module.file is not None:
                     parts = mod_name_parts.copy()
                     if module.code is None:
-                        parts.pop()
+                        # if a module init is distributed as compiled like
+                        # __init__.pyd, its name should be preserved.
+                        if not module.file.name.startswith("__init__."):
+                            parts.pop()
                         parts.append(module.file.name)
                         target_name = target_lib_dir.joinpath(*parts)
                         self._copy_file(
@@ -704,6 +735,8 @@ class Freezer:
                 # otherwise, write to the zip file
                 elif module.code is not None:
                     zip_time = time.localtime(mtime)[:6]
+                    if zip_time[0] < 1980:
+                        zip_time = (1980, 1, 1, 0, 0, 0)
                     target_name = "/".join(mod_name_parts)
                     if module.path:
                         target_name += "/__init__"
@@ -764,12 +797,11 @@ class Freezer:
         finder: ModuleFinder = self.finder
 
         # Add the executables to target
-        for i, executable in enumerate(self.executables):
+        executables = []
+        for executable in self.executables:
             self._freeze_executable(executable)
-            finder.add_constant(
-                f"_EXECUTABLE_NAME_{i}", executable.target_name
-            )
-        finder.add_constant("_EXECUTABLES_NUMBER", len(self.executables))
+            executables.append(executable.target_name)
+        finder.add_constant("__EXECUTABLES__", os.pathsep.join(executables))
 
         # Write the modules
         self._write_modules()
