@@ -1,14 +1,9 @@
-from __future__ import annotations
-
 import sys
-from datetime import datetime
+from datetime import datetime, timezone
 
+today = datetime.now(tz=timezone.utc)
 print("Hello from cx_Freeze")
-print(
-    "The current date is {}\n".format(
-        datetime.today().strftime("%B %d, %Y %H:%M:%S")
-    )
-)
+print(f"The current date is {today:%B %d, %Y %H:%M:%S}\n")
 
 print(f"Executable: {sys.executable}")
 print(f"Prefix: {sys.prefix}")
@@ -16,13 +11,13 @@ print(f"Default encoding: {sys.getdefaultencoding()}")
 print(f"File system encoding: {sys.getfilesystemencoding()}\n")
 
 print("ARGUMENTS:")
-for a in sys.argv:
-    print(f"{a}")
-print("")
+for arg in sys.argv:
+    print(f"{arg}")
+print()
 
 print("PATH:")
-for p in sys.path:
-    print(f"{p}")
+for path in sys.path:
+    print(f"{path}")
 print()
 
 input("Press Enter to continue...")
