@@ -33,6 +33,7 @@ pyproject.toml
     executables = ["test_argon2.py"]
 
     [tool.cxfreeze.build_exe]
+    include_msvcr = true
     excludes = ["tkinter", "unittest"]
     silent = true
 """
@@ -54,7 +55,7 @@ pyproject.toml
 @zip_packages
 def test_argon2(tmp_package, zip_packages) -> None:
     """Test if argon2-cffi is working correctly."""
-    tmp_package.map_package_to_mingw["argon2-cffi"] = "argon2_cffi"
+    tmp_package.map_package_to_mingw["argon2-cffi"] = "python-argon2_cffi"
     tmp_package.create(SOURCE_ARGON2)
     if zip_packages:
         pyproject = tmp_package.path / "pyproject.toml"
@@ -87,6 +88,7 @@ pyproject.toml
     executables = ["test_bcrypt.py"]
 
     [tool.cxfreeze.build_exe]
+    include_msvcr = true
     excludes = ["tkinter", "unittest"]
     silent = true
 """
@@ -139,6 +141,7 @@ pyproject.toml
     executables = ["test_crypto.py"]
 
     [tool.cxfreeze.build_exe]
+    include_msvcr = true
     excludes = ["tkinter", "unittest"]
     silent = true
 """
@@ -183,6 +186,7 @@ pyproject.toml
     executables = ["test_cryptography.py"]
 
     [tool.cxfreeze.build_exe]
+    include_msvcr = true
     excludes = ["tkinter", "unittest"]
     silent = true
 """
