@@ -2,12 +2,8 @@
 
 from __future__ import annotations
 
-import sys
-
 import pytest
 
-from cx_Freeze._compat import ABI_THREAD, IS_ARM_64, IS_WINDOWS
-
 TIMEOUT = 10
 
 zip_packages = pytest.mark.parametrize(
@@ -36,18 +32,6 @@ pyproject.toml
 """
 
 
-@pytest.mark.xfail(
-    IS_WINDOWS and IS_ARM_64,
-    raises=ModuleNotFoundError,
-    reason="pyproj does not support Windows arm64",
-    strict=True,
-)
-@pytest.mark.xfail(
-    sys.version_info[:2] >= (3, 13) and ABI_THREAD == "t",
-    raises=ModuleNotFoundError,
-    reason="pyproj does not support Python 3.13t",
-    strict=True,
-)
 @pytest.mark.venv
 @zip_packages
 def test_pyproj(tmp_package, zip_packages: bool) -> None:
